using Knoks.Core.Entities;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace Knoks.Core.Data.Interfaces
{
    public interface IAccountDao
    {
        Task<UserAccounts> GetUserAccounts(long userId);
        Task<IEnumerable<int>> GetFavorites(long? contextUserId);
        Task<IEnumerable<int>> AddFavorite(long? contextUserId, int knokId);
        Task<IEnumerable<int>> RemoveFavorite(long? contextUserId, int knokId);
        Task<IEnumerable<long>> GetFollows(long? contextUserId);
        Task<IEnumerable<long>> AddFollow(long? contextUserId, long userId);
        Task<IEnumerable<long>> RemoveFollow(long? contextUserId, long userId);
    }
}
